@@ -81,11 +81,11 @@ class Controller:
       m = {"command":"ack", "id":idn}
       self.pjson(m)
 
-  def fail(self, idn):
-    if idn == None:
-      self.log("Invalid id")
+  def fail(self, message):
+    if message == None:
+      self.log("no error message")
     else:
-      m = {"command":"fail", "id":idn}
+      m = {"command":"fail", "msg":message}
       self.pjson(m)
 
   def done(self):
