@@ -24,24 +24,20 @@ class Each:
     if self._prepare != None:
       self._prepare(controller)
 
-    try:
-      while True:
+    while True:
+      try:
         d = controller.read()
         if d == None:
           continue
         tup = controller.get_tuple(d)
         if tup == None:
           continue
-        try:
-          self._execute(controller, tup)
-          controller.done()
-        except:
-          controller.log("Error in execute function")
-          raise
-    except KeyboardInterrupt:
-      raise
-    except ParentDeadException, e:
-      controller.log("jvm appears to have died")
-      raise
-    except:
-      controller.log("Exception in each: "+traceback.format_exc())
+        self._execute(controller, tup)
+      except KeyboardInterrupt:
+        raise
+      except ParentDeadException, e:
+        controller.log("jvm appears to have died")
+        raise
+      except:
+        controller.fail("Exception in each: "+traceback.format_exc())
+      controller.done()
