@@ -23,8 +23,8 @@ class Filter:
     if self._prepare != None:
       self._prepare(controller)
 
-    try:
-      while True:
+    while True:
+      try:
         d = controller.read()
         if d == None:
           continue
@@ -33,11 +33,11 @@ class Filter:
           continue
         if self._keep(tup):
           controller.emit(tup)
-        controller.done()
-    except KeyboardInterrupt:
-      raise
-    except ParentDeadException, e:
-      controller.log("jvm appears to have died")
-      raise
-    except:
-      controller.log("Exception in filter: "+traceback.format_exc())
+      except KeyboardInterrupt:
+        raise
+      except ParentDeadException, e:
+        controller.log("jvm appears to have died")
+        raise
+      except:
+        controller.fail("Exception in filter: "+traceback.format_exc())
+      controller.done()
