@@ -32,8 +32,8 @@ class Source:
   def run(self, controller):
     controller.get_pidDir()
 
-    try:
-      while True:
+    while True:
+      try:
         d = controller.read()
         if d == None:
           continue
@@ -43,21 +43,20 @@ class Source:
           if(self._begin_cycle != None):
             self._begin_cycle(controller)
         elif d["command"] == "next":
-          try:
             self._next_tuple(controller)
-          except UserEndCycleException, e:
-            pass
         elif d["command"] == "ack":
           controller.ack(d.get("id",None))
         elif d["command"] == "fail":
           controller.fail(d.get("id",None))
         else:
           controller.log("Invalid command")
-        controller.done()
-    except KeyboardInterrupt:
-      raise
-    except ParentDeadException, e:
-      controller.log("jvm appears to have died")
-      raise
-    except:
-      controller.log("Exception in source: "+traceback.format_exc())
+      except UserEndCycleException, e:
+        pass
+      except KeyboardInterrupt:
+        raise
+      except ParentDeadException, e:
+        controller.log("jvm appears to have died")
+        raise
+      except:
+        controller.fail("Exception in source: "+traceback.format_exc())
+      controller.done()
